@@ -8,6 +8,7 @@ import re
 
 def _extract_table_names(q):
     "extracts table names from a sql query"
+
     tables = set()
     next_is_table = False
     for query in sqlparse.parse(q):
@@ -24,6 +25,7 @@ def _extract_table_names(q):
 
 def _write_table(tablename, df, conn):
     "writes a dataframe to the sqlite database"
+
     for col in df.columns:
         if re.search("[() ]", col):
             msg = "please follow SQLite column naming conventions: "
@@ -33,13 +35,16 @@ def _write_table(tablename, df, conn):
     write_frame(df, name=tablename, con=conn, flavor='sqlite')
 
 
-def sqldf(q, env):
+def sqldf(q, env, dbtype=':memory:'):
     """
     query pandas data frames using sql syntax
 
     q: a sql query using DataFrames as tables
-    env: variable environment; you must include locals() or globals() in your function
-         call to allow sqldf to access the variables in your python environment
+    env: variable environment; locals() or globals() in your function
+         allows sqldf to access the variables in your python environment
+    dbtype: memory/disk
+        default is in memory; if not memory then it will be temporarily
+        persisted to disk
 
     Example
     -----------------------------------------
@@ -52,10 +57,14 @@ def sqldf(q, env):
     sqldf("select * from df;", locals())
     sqldf("select avg(x) from df;", locals())
     """
-    conn = sqlite.connect('.pandasql.db', detect_types=sqlite.PARSE_DECLTYPES)
+
+    conn = sqlite.connect(sqlite_database, detect_types=sqlite.PARSE_DECLTYPES)
     tables = _extract_table_names(q)
     for table in tables:
         if table not in env:
+            conn.close()
+            if sqlite_database != ':memory:' :
+                os.remove(sqlite_database)
             raise Exception("%s not found" % table)
         df = env[table]
         _write_table(table, df, conn)
@@ -65,5 +74,6 @@ def sqldf(q, env):
         result = None
     finally:
         conn.close()
-        os.remove('.pandasql.db')
+        if sqlite_database != ':memory:' :
+            os.remove(sqlite_database)
     return result
